@@ -1,8 +1,11 @@
 package testcover;
-use FindBin;
-use TAP::Harness;
-use File::Glob qw(bsd_glob);
+use Config;
+use Data::Dumper;
 use Devel::Cover::DB;
+use File::Glob qw(bsd_glob);
+use FindBin;
+use List::Util qw(first);
+use TAP::Harness;
 
 sub run {
     my $name = shift;
@@ -19,22 +22,35 @@ sub run {
     my @tests = bsd_glob("$path/*.t");
     $harness->runtests(@tests);
 
-    my $cover_cmd = `which cover`;
-    chomp($cover_cmd);
-    run_cmd( $cover_cmd, $cover_db );
+    my $cover_cmd = p_which('cover');
+
+    if ( !$cover_cmd ) {
+        die( 'Missing "cover". %Config:' . Dumper( \%Config ) );
+    }
+
+    my $path_to_perl = $Config{perlpath};
+    run_cmd( $path_to_perl, $cover_cmd, $cover_db );
 
     my $db = Devel::Cover::DB->new( db => $cover_db );
     return $db;
 
 }
 
+sub p_which {
+    my $command = shift;
+
+    return first {-f}
+    map {"$_/$command"} @Config{qw/installscript installsitebin installvendorbin installbin/};
+
+}
+
 sub run_cmd {
     my @parts = @_;
     my $str = sprintf( "'%s'", join "','", @parts );
     {
         local *STDOUT = STDOUT;
         open( STDOUT, '>', '/dev/null' );
-        system(@parts) == 0 or die "system($str) failed: $?";
+        system(@parts) == 0 or die "system($str) failed: $? \n" . Dumper( \%Config );
     }
     return;
 }
